@@ -2,12 +2,12 @@ import argparse
 import logging
 
 from confuse import NotFoundError
+from pygraphviz import AGraph
+
 from dotifi.configuration.load import load_configuration
 from dotifi.nifi import generate
 from dotifi.nifi.connection import configure_nifi_connection
 from dotifi.publishing.publish import publish
-from pygraphviz import AGraph
-
 
 """
 dotifi main script
@@ -41,7 +41,7 @@ def process():
         "-o",
         required=False,
         default="nifi-canvas",
-        help="Path to the dot file to store the dot results to.",
+        help="Path to the gv file to store the dot results to.",
     )
     parser.add_argument(
         "--output-graphviz-format",
@@ -100,7 +100,7 @@ def process():
         "-g",
         required=False,
         default="nifi-canvas",
-        help="Path to the dot file to store the graphviz results to. "
+        help="Path to the graphical file to store the graphviz results to. "
         + "Results will be saved with the extension "
         + "of the --output-graphviz-format option",
     )
@@ -130,12 +130,14 @@ def process():
     )
     parser.add_argument(
         "--using-ssl",
+        action="store_true",
         required=False,
         default=False,
         help="Flag, when specified it signals that the NiFi connection requires SSL",
     )
     parser.add_argument(
         "--using-user-pw",
+        action="store_true",
         required=False,
         default=False,
         help="Flag, when specified it signals that the NiFi connection requires a username and password",
@@ -160,6 +162,16 @@ def process():
         required=False,
         help="The password to decrypt the client_key_file",
     )
+    parser.add_argument(
+        "--auth-token",
+        required=False,
+        help="Authorization token string",
+    )
+    parser.add_argument(
+        "--auth-token-api-field",
+        required=False,
+        help="the api_key field name to set the token to. Defaults to 'tokenAuth'",
+    )
     parser.add_argument("--nifi-username", required=False, help="The NiFi user name")
     parser.add_argument(
         "--nifi-user-password", required=False, help="The NiFi user password"
